@@ -1,12 +1,12 @@
 __title__ = 'DRF writable nested'
-__version__ = '0.4.2'
+__version__ = '0.6.0'
 __author__ = 'beda.software'
 __license__ = 'BSD 2-Clause'
-__copyright__ = 'Copyright 2014-2018 beda.software'
+__copyright__ = 'Copyright 2014-2020 beda.software'
 
 # Version synonym
 VERSION = __version__
 
 
-from .mixins import NestedUpdateMixin, NestedCreateMixin
+from .mixins import NestedUpdateMixin, NestedCreateMixin, UniqueFieldsMixin
 from .serializers import WritableNestedModelSerializer
